import { Position } from './types/anim.js';
import { CAnimControl, CAnimation } from './module/canimctrl.js';
/** Control object for animation. */
export declare class AnimControl {
    private _cControl;
    constructor(cControl: CAnimControl);
    /** Returns a reference to the actual animation for further reuse. */
    store(): CAnimation;
    /** Seeks the animation to the position specified by time or progress
    percentage. Seeking the animation to the end position while the animation
    is paused will not trigger the animation complete promise to resolve. */
    seek(value: Position): this;
    /** Setting the playback speed of the animation. It is 1.0 by default.
    Negative values are considered 0. */
    set speed(value: number);
    /** Getting the playback speed of the animation. */
    get speed(): number;
    /** Setting the playback state of the animation. */
    set playState(value: 'running' | 'paused');
    /** Getting the playback state of the animation. */
    get playState(): 'running' | 'paused';
    /** Setting the play direction of the animation. */
    set direction(value: 'normal' | 'reverse');
    /** Getting the play direction of the animation. */
    get direction(): 'normal' | 'reverse';
    /** Setting the position of the animation. */
    set position(value: number);
    /** Getting the position of the animation. */
    get position(): number;
    /** @deprecated Pauses the controlled animation. */
    pause(): this;
    /** @deprecated Plays/resumes playing of the controlled animation. */
    play(): this;
    /** Stops the current animation seeking it back to its start position. */
    stop(): this;
    /** Cancels the animation, will reject the animation promise. */
    cancel(): this;
    /** @deprecated Changes the direction of the controlled animation to reverse. */
    reverse(): this;
    private _setParam;
    private _getParam;
}
